def get_classes():

    from ImageViewer import ImageViewer
    from ImageThumbnailer import ImageThumbnailer
    from ImageInspector import ImageInspector
    
    return [ImageViewer,
            ImageThumbnailer,
            ImageInspector]

